@@ -8,12 +8,10 @@ from . import xyfile
 from . import geojson
 from . import gpx
 from . import vtk
-from . import shapefile
-from . import shp_funcs
 
 from .guppy import Point, Multipoint, Line, Polygon
 from .read import read_geojson, read_geojson_features, read_shapefile
-from .shp_funcs import write_shapefile
+from ._shpfuncs import write_shapefile
 from .gpx import GPX
 from .xyfile import load_xy, xyz2array_reg, array2xyz
 
@@ -23,7 +21,7 @@ except ImportError:
     # Probably missing scipy dependency
     pass
 
-__all__ = ["guppy", "xyfile", "geojson", "gpx", "vtk", "shapefile", "shp_funcs",
+__all__ = ["guppy", "xyfile", "geojson", "gpx", "vtk",
            "Point", "Multipoint", "Line", "Polygon",
            "read_geojson", "read_geojson_features", "read_shapefile",
            "write_shapefile",
